set matsize 3500
use campaign_contributions_over_ceo_careers.dta, clear

*TABLE 1 - Summary Statistics

*TABLE 2 - Effect of Being CEO of an S&P500 Firm on Dollar Amount of Political Contributions Given

*Model I: Total Contribution Amounts in Dollars
xi: regress amt_total_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model II: Total Contribution Amounts in Dollars to Candidates
xi: regress amt_to_cands_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model III: Total Contribution Amounts in Dollars to PACs
xi: regress amt_to_pacs_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model IV: Total Contribution Amounts in Dollars to Parties
xi: regress amt_to_parties_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0


*TABLE 3 - Effect of Being CEO of an S&P500 Firm on the Intensive and Extensive Margins of Campaign Contributions

*Model I: Only Individuals who made Contributions Prior to Becoming CEO
xi: regress amt_total_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_give_intensive==1 & dum_born_ceo==0

*Model II: Only Individuals who Did Not Contribute Prior to Becoming CEO, but Gave After
xi: regress amt_total_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_give_extensive_str==1 & dum_born_ceo==0

*Model III: Only Individuals who Did Not Contribute Prior to Becoming CEO
xi: regress amt_total_clean dum_ceo dum_ceo_former i.execid i.cycle_year if dum_give_intensive==0 & dum_born_ceo==0


*TABLE 4 - ROBUSTNESS/ FALSIFICATION

*Proprietary Data from EXECUCOMP Dataset is required for additional control variables used in this table

*Two forms of proprietary data are needed:
*1) executive salary data, and
*2) executive ownership share data

*These were downloaded from EXECUCOMP using EXECID as a unique identifier which can be used to merge these data into the dataset we are posting on campaign contributions.

*The Executive Salary data is then transformed three ways to create the data necessary to run these regressions
*exec_comp_sal_fil_zer - transforms missing entries for periods where an indiviudal (demarked by his unique EXECID) has blank data or does not appear in EXECUCOMP to dollar values of salary in exsiting years and zero otherwise.
*exec_comp_sal_fil_min - transforms missing entries for periods where an indiviudal (demarked by his unique EXECID) has blank data or does not appear in EXECUCOMP to dollar values of salary in exsiting years and his minimum existing salary in other years
*exec_comp_sal_fil_min - transforms missing entries for periods where an indiviudal (demarked by his unique EXECID) has blank data or does not appear in EXECUCOMP to dollar values of salary in exsiting years and his maximum existing salary in other years 

*The executive ownership share data 
*exec_comp_oweno_pct - this is the fraction of the firm's total shares that the executive owns;  missing entries and entries for periods where an individual (demarked by his unique EXECID) are filled with zeros

*NOTE these regressions will not run without merging in and appropriately tranforming variables from EXECUCOMP as described above

*Model I
*xi: regress amt_total_clean dum_ceo dum_ceo_former exec_comp_sal_fil_zer i.execid i.cycle_year if dum_born_ceo==0 

*Model II
*xi: regress amt_total_clean dum_ceo dum_ceo_former exec_comp_sal_fil_min i.execid i.cycle_year if dum_born_ceo==0 

*Model III
*xi: regress amt_total_clean dum_ceo dum_ceo_former exec_comp_sal_fil_max i.execid i.cycle_year if dum_born_ceo==0 

*Model IV
*xi: regress amt_total_clean dum_ceo dum_ceo_former exec_comp_owneo_pct i.execid i.cycle_year if dum_born_ceo==0 

*Model V
*xi: regress amt_total_clean dum_ceo dum_ceo_former exec_comp_owneo_pct exec_comp_sal_fil_zer i.execid i.cycle_year if dum_born_ceo==0 

*Model VI
*xi: regress amt_total_clean dum_ceo_internal dum_ceo_external dum_ceo_former exec_comp_owneo_pct exec_comp_sal_fil_zer*1000 i.execid i.cycle_year if dum_born_ceo==0 

*TABLE A1 - Contribution Limits
*This data comes from FEC rules

*TABLE B1 - Counts
*Model 1
nbreg count_total_uniq_recip dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model 2
nbreg count_cands dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model 3
nbreg count_pacs dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model 4
nbreg count_party_cmtes dum_ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*TABLE C1 - Partisanship
*Model 1
xi: regress partisian_r_parties dum_Ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0

*Model 2
xi: regress partisian_r_cands dum_Ceo dum_ceo_former i.execid i.cycle_year if dum_born_ceo==0
